OakVar

JOBS
STORE
ADMIN
System update available
Version:

Variants
Genome:
Add input files
Example: OR
Note:
Annotations Additional Analysis |
Job ID | Input File | Variants | Annotators | Genome | Note | Status | Download | Delete
--- | --- | --- | --- | --- | --- | --- | --- | ---

Update available

By Category

Sort by
There are missing system modules which OakVar needs.
Click this button to install them:
System updates in progress...
System configuration file:
Jobs dir:
Modules dir:
Limit the sum of input file sizes to: MB
Maximum number of concurrent jobs:
Maximum number of concurrent annotators per job:

Lost connection to the server.
Please launch OakVar again.
Uploading input file(s)...
Updating store information...
Choose a report type: